Administration — CubicWeb 3.11.0

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »

# Administration

This part is for installation and administration of the CubicWeb framework and instances based on that framework.

- 1. Installation and set-up of a CubicWeb environment
- 2. `cubicweb-ctl` tool
- 3. Creation of your first instance
- 4. Configure an instance
- 5. User interface for web site configuration
- 6. Multiple sources of data
- 7. LDAP integration
- 8. Working with a distributed client (using Pyro)
- 9. CubicWeb in Google AppEngine
- 10. Migrating cubicweb instances - benefits from a distributed architecture
- 11. Backups (mostly with postgresql)
- 12. RQL logs

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »